==> autopaths-1.3.8.tar.gz: autopaths-1.3.8/autopaths/file_size.py <==
# Built-in modules #
from math import log

################################################################################
class FileSize(object):
    """
    Container for a size in bytes with a human readable representation
    Use it like this:

        >>> from autopaths.file_size import FileSize
        >>> size = FileSize(123123123)
        >>> print size
        '123.1 MB'
        >>> size = FileSize(123123123, system='binary')
        >>> print size
        '117.4 MiB'
    """

    precisions = [0, 0, 1, 2, 2, 2]

    def __init__(self, size, system='decimal'):
        # Record the size #
        self.size = size
        # Pick the system used #
        if system is 'binary':
            self.chunk = 1024
            self.units = ['bytes', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB']
        elif system is 'decimal':
            self.chunk = 1000
            self.units = ['bytes', 'KB', 'MB', 'GB', 'TB', 'PB']
        else:
            raise Exception("Unrecognized file size system '%s'" % system)

    def __eq__(self, other):
        return self.size == other

    def __str__(self):
        # Special cases #
        if self.size == 0: return '0 bytes'
        if self.size == 1: return '1 byte'
        # Pick the right unit #
        unit = self.units[min(int(log(self.size, self.chunk)), len(self.units) - 1)]
        # Compute #
        exponent  = self.units.index(unit)
        quotient  = float(self.size) / self.chunk**exponent
        precision = self.precisions[exponent]
        template  = '{:.%sf} {}' % (precision)
        string    =  template.format(quotient, unit)
        # Return a string #
        return string

==> autopaths-1.5.9.tar.gz: autopaths-1.5.9/autopaths/file_size.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Written by Lucas Sinclair.
MIT Licensed.
Contact at www.sinclair.bio
"""

# Built-in modules #
from math import log

################################################################################
class FileSize(object):
    """
    Container for a size in bytes with a human readable representation
    Use it like this:

        >>> from autopaths.file_size import FileSize
        >>> size = FileSize(123123123)
        >>> print size
        '123.1 MB'
        >>> size = FileSize(123123123, system='binary')
        >>> print size
        '117.4 MiB'
    """

    precisions = [0, 0, 1, 2, 2, 2]

    def __init__(self, size, system='decimal'):
        # Record the size #
        self.size = size
        # Pick the system used #
        if system == 'binary':
            self.chunk = 1024
            self.units = ['bytes', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB']
        elif system == 'decimal':
            self.chunk = 1000
            self.units = ['bytes', 'KB', 'MB', 'GB', 'TB', 'PB']
        else:
            raise Exception("Unrecognized file size system '%s'" % system)

    def __eq__(self, other):
        return self.size == other

    def __str__(self):
        # Special cases #
        if self.size == 0: return '0 bytes'
        if self.size == 1: return '1 byte'
        # Pick the right unit #
        index = min(int(log(self.size, self.chunk)), len(self.units) - 1)
        unit = self.units[index]
        # Compute #
        exponent  = self.units.index(unit)
        quotient  = float(self.size) / self.chunk**exponent
        precision = self.precisions[exponent]
        template  = '{:.%sf} {}' % precision
        string    =  template.format(quotient, unit)
        # Return a string #
        return string
